@@ -71,6 +71,22 @@ class RevisionAdded(hook.Hook):
             operation.add_data((repo.eid, self.entity.eid))
 
 
+class RevisionObsoleteHook(hook.Hook):
+    """detect new obsolete revision"""
+    __regid__ = 'vcreview.obsolete_rev'
+    __select__ = hook.Hook.__select__ & hook.match_rtype('obsoletes')
+    events = ('after_add_relation',)
+
+    def __call__(self):
+        rev = self._cw.entity_from_eid(self.eidfrom)
+        if rev.reverse_patch_revision:
+            return
+        repo = rev.repository
+        if getattr(repo, 'has_review', False):
+            operation = AttachToPatchesOp.get_instance(self._cw)
+            operation.add_data((repo.eid, rev.eid))
+
+
 class RevisionDeleted(hook.Hook):
     """When deleting a revision, delete the associated patch if it has
     no other revisions
@@ -82,7 +98,7 @@ class RevisionDeleted(hook.Hook):
 
     def __call__(self):
         patch = self.entity.reverse_patch_revision[0]
-        PatchLifeCheckOp.get_instance(self._cw).add_data((self.entity.repository.eid, patch.eid, None))
+        DeletedRevisionCheckOp.get_instance(self._cw).add_data(patch.eid)
 
 
 class AttachToPatchesOp(hook.DataOperationMixIn, hook.LateOperation):
@@ -142,7 +158,7 @@ class AttachToPatchesOp(hook.DataOperationMixIn, hook.LateOperation):
 
 
     def create_patch(self, rev):
-        name = rev.description.splitlines()[0]
+        name = (rev.description.splitlines() or [rev.dc_title()])[0]
         kwargs = {'patch_name': name, 'patch_revision': rev}
         users = users_by_author(self.session.execute, rev.author)
         if users:
@@ -152,6 +168,19 @@ class AttachToPatchesOp(hook.DataOperationMixIn, hook.LateOperation):
         self.info(msg, rev.repository.dc_title(), patch.eid, rev.changeset)
         return patch
 
+
+class DeletedRevisionCheckOp(hook.DataOperationMixIn, hook.Operation):
+    """Delete patches with no remaining revision"""
+    def precommit_event(self):
+        for patch_eid in self.get_data():
+            rset = self.session.execute(
+                    'DELETE Patch P WHERE P eid %(eid)s,'
+                    '                     NOT EXISTS(P patch_revision R)',
+                    {'eid': patch_eid})
+            if rset:
+                self.info('Deleted patch %s, no revisions left', rset[0][0])
+
+
 class PatchLifeCheckOp(hook.DataOperationMixIn, hook.SingleLastOperation):
     """Put patches in the right state
 
@@ -180,14 +209,6 @@ class PatchLifeCheckOp(hook.DataOperationMixIn, hook.SingleLastOperation):
             # nothing to be done on it anymore
             if patch.is_final:
                 continue
-            if eid_rev is None:
-                rset = self.session.execute(
-                        'DELETE Patch P WHERE P eid %(eid)s,'
-                        '                     NOT EXISTS(P patch_revision R)',
-                        {'eid': patch.eid})
-                if rset:
-                    self.info('Deleted patch %s, no revisions left', rset[0][0])
-                continue
             rev = session.entity_from_eid(eid_rev)
             assert rev.reverse_patch_revision
             ### Case 2: patch has just been applied
@@ -211,6 +232,9 @@ class PatchLifeCheckOp(hook.DataOperationMixIn, hook.SingleLastOperation):
                 if self._is_rebase(rev, wfable.state):
                     continue
                 ### Case 3: new version of the patch
+                name = (rev.description.splitlines() or [rev.dc_title()])[0]
+                if name != patch.patch_name:
+                    patch.cw_set(patch_name=name)
                 if wfable.state != 'pending-review':
                     wfable.fire_transition('ask review', u'new version %s'
                                            % rev.changeset)
