@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from cubicweb.mttransforms import ENGINE
 
 from cubes.vcsfile.docparser import Diff2HTMLTransform
 
@@ -47,6 +46,10 @@ def insert_point_callback(ipid, trdata, w):
             comp.render(w=w)
     w(u'</div>')
 
-if Diff2HTMLTransform.name in ENGINE.transforms:
-    ENGINE.remove_transform(Diff2HTMLTransform.name, 'text/x-diff')
-ENGINE.add_transform(Diff2HTMLTransform(insert_point_callback))
+def register_transforms(engine, verb=True):
+    if Diff2HTMLTransform.name in engine.transforms:
+        engine.remove_transform(Diff2HTMLTransform.name, 'text/x-diff')
+    engine.add_transform(Diff2HTMLTransform(insert_point_callback))
+
+from cubicweb.mttransforms import ENGINE
+register_transforms(ENGINE)
