@@ -13,6 +13,7 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
                                                     'rejected')
 
     content = StatusChangeMixIn.content + '''
+%(reviewer)s
 
 %(patch)s
 '''
@@ -53,6 +54,11 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
                 patch = patch[:MAX_PATCH_SIZE] + '\n@@ truncated patch @@'
             context['patch'] = patch
 
+        if entity.patch_reviewer:
+            context['reviewer'] = self._cw._('reviewer: ') + ', '.join([user.dc_title() for user in entity.patch_reviewer])
+        else:
+            context['reviewer'] = self._cw._('reviewer: ')
+
         return context
 
 
