@@ -34,6 +34,12 @@ class DiffParserTC(TestCase):
         except KeyError:
             pass
 
+    @classmethod
+    def tearDownClass(cls):
+        # reset to defaults
+        from cubes.vcreview.site_cubicweb import register_transforms
+        register_transforms(ENGINE)
+
     def transform(self, file):
         data = open(self.datapath(file)).read()
         trdata = TransformData(data, 'text/x-diff', 'utf-8')
