@@ -33,6 +33,9 @@ from cubes.vcsfile import bridge
 
 from cubes.vcsfile.testutils import init_vcsrepo
 
+from mercurial.__version__ import version as hgversion
+hg26 = (tuple(int(x) for x in hgversion.split('.')[:2]) >= (2, 6))
+
 def revnums(patch):
     return sorted(vc.revision for vc in patch.patch_revision)
 
@@ -82,7 +85,7 @@ class HgHelper(CubicWebTC):
 
     def refresh(self):
         """Have cubicweb read the on disk repo"""
-        with self.repo.internal_session() as session:
+        with self.repo.internal_session(safe=True) as session:
             bridge.import_content(session, raise_on_error=True)
             session.commit()
 
@@ -188,6 +191,15 @@ class PatchLifeCycleTC(HgHelper):
         wf_history = self.get_wf_history(patch)
         self.assertEqual(['pending-review', 'applied'], wf_history)
 
+    def test_empty_desc(self):
+        self.test_root_publishing()
+        hg = self.call_hg
+        a = self.append_to
+
+        a('jungle', 'Pam')
+        hg('commit', '-m', ' ')  # sic
+        self.refresh()
+
     def test_simple_amend(self):
         self.test_root_publishing()
         hg = self.call_hg
@@ -199,42 +211,43 @@ class PatchLifeCycleTC(HgHelper):
 
         # add a new draft children again
         a('jungle', 'Pam')
-        hg('commit', '-m', 'fisrt child')  # sic
+        hg('commit', '-m', 'XXX')  # sic
         self.refresh()
 
         # We should have a new Patch linked to revision 1
         rev = self.all_revs()[-1]
-        assert rev.description == 'fisrt child'
+        assert rev.description == 'XXX'
         self.assertTrue(rev.reverse_patch_revision)
         patch = rev.reverse_patch_revision[0]
         self.assertNotEqual(oldpatch.eid, patch.eid)
-        self.assertEqual('fisrt child', patch.patch_name)
+        self.assertEqual('XXX', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('pending-review', patch_state)
         wf_history = self.get_wf_history(patch)
         self.assertEqual(['pending-review'], wf_history)
 
-        # Fix changeset content
+        # Fix changeset content and description
         path = osp.join(self.tmprepo, 'jungle')
         with open(path, 'r') as f:
             data = f.read().replace('Pam', 'Pom')
         with open(path, 'w') as f:
             f.write(data)
-        hg('commit', '--amend', '-m', 'firts child')
+        hg('commit', '--amend', '-m', 'first child')
         self.refresh()
         # test that the new revision is added to the same patch
         patch.cw_clear_all_caches()
         rev = self.all_revs()[-1]
-        assert rev.description == 'firts child'
+        assert rev.description == 'first child'
         newpatch = rev.reverse_patch_revision[0]
         self.assertEqual(patch.eid, newpatch.eid)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('pending-review', patch_state)
         wf_history = self.get_wf_history(patch)
         self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual('first child', patch.patch_name)
 
         # yet another successor. A public one
-        hg('commit', '--amend', '-m', 'first child')
+        hg('commit', '--amend', '-m', 'First child')
         hg('phase', '--public', '.')
         self.refresh()
         patch.cw_clear_all_caches()
@@ -366,7 +379,7 @@ class PatchLifeCycleTC(HgHelper):
         assert rev.description == 'second child'
         self.assertTrue(rev.reverse_patch_revision)
         eid_patch = rev.reverse_patch_revision[0].eid
-        with self.repo.internal_session() as session:
+        with self.repo.internal_session(safe=True) as session:
             self.assertTrue(session.execute('DELETE Revision R WHERE R eid %(eid)s',
                                             {'eid': rev.eid}))
             session.commit()
@@ -488,6 +501,36 @@ class PatchLifeCycleTC(HgHelper):
         wf2_history = self.get_wf_history(patch2)
         self.assertEqual(['pending-review', 'folded'], wf2_history)
 
+    def test_late_obsolete(self):
+        hg = self.call_hg
+        a = self.append_to
+
+        # create a simple root changeset as draft
+        a('jungle', 'Babar')
+        hg('add', osp.join(self.tmprepo, 'jungle'))
+        hg('commit', '-m', 'Initial jungle content')
+        self.refresh()
+
+        # create an unrelated public cs
+        hg('up', 'null')
+        a('jungle', 'Babar')
+        hg('add', osp.join(self.tmprepo, 'jungle'))
+        hg('commit', '-m', 'Amended jungle content')
+        hg('phase', '-p', '.')
+        self.refresh()
+
+        # add obsolete relation
+        hg('debugobsolete', self.get_id('0'), self.get_id('1'))
+        self.refresh()
+
+        rev0 = self.all_revs()[0]
+        self.assertEqual(1, len(rev0.reverse_patch_revision))
+        self.assertEqual(1, len(rev0.reverse_obsoletes))
+        self.assertEqual(self.all_revs()[1].changeset, rev0.reverse_obsoletes[0].changeset)
+        patch = rev0.reverse_patch_revision[0]
+        self.assertEqual('applied', patch.cw_adapt_to('IWorkflowable').state)
+
+
 class PatchNotificationTC(CubicWebTC):
 
     @classmethod
@@ -538,13 +581,13 @@ class PatchNotificationTC(CubicWebTC):
         got = email.content.splitlines()
         # we should print a diff like -/+ stuff
         for idx, line in enumerate(expected):
-            self.assertMatches('^' + line + '$', got[idx])
+            self.assertMatches('^' + line + '$', got[idx], idx)
         self.assertEqual(len(expected), len(got))
 
-    def assertMatches(self, expected, got):
+    def assertMatches(self, expected, got, lineno):
         """ expected is a regular expression """
         self.assertTrue(re.match(expected, got),
-                        '%r\n does not match:\n %r' % (got, expected))
+                'line %d: %r\n does not match:\n %r' % (lineno, got, expected))
 
 
     def test_nosy_list_author(self):
@@ -600,10 +643,12 @@ class PatchNotificationTC(CubicWebTC):
                               '\n'
                               'url: http://testing.fr/cubicweb/patch/\d+\n'
                               '\n'
+                              'reviewer: Ba(bar|sile)\n'
                               '\n'
                               '# HG changeset patch\n'
                               '# User Victor <victor@ratax.es>\n'
                               '# Date 1361805588 0\n'
+                              '%s' # optional human-readable date
                               '# Node ID bfa5da61c82507b76dae7927b4fce2aa4a0c9c6f\n'
                               '# Parent  549cd3165597cdd5c9d8fa26e83e63483fcfb4b5\n'
                               'Add more elephants children\n'
@@ -627,7 +672,8 @@ class PatchNotificationTC(CubicWebTC):
                               ' \n'
                               " if __name__ == '__main__':\n"
                               "     print 'Those are elephants:'\n"
-                              '\n')
+                              '\n' %
+                              '#      Mon Feb 25 15:19:48 2013 \+0000\n' if hg26 else '')
         # add task
         MAILBOX[:] = ()
         task = session.create_entity('Task', title=u'todo', reverse_has_activity=patch)
@@ -659,6 +705,7 @@ class PatchNotificationTC(CubicWebTC):
                               '\n'
                               'url: http://testing.fr/cubicweb/patch/\d+\n'
                               '\n'
+                              'reviewer: Ba(bar|sile)\n'
                               '\n'
                               '\n')
 
