@@ -141,13 +141,13 @@ class PatchReviewWorkflowTC(CubicWebTC):
         req.execute('SET X repository_reviewer U WHERE U login "committer"')
         patch = req.entity_from_eid(self.patch1eid)
         ireview = patch.cw_adapt_to('IPatchReviewControl')
-        self.assertEqual(set(x for x, in ireview.reviewers_rset().rows),
+        self.assertEqual(set(x for x,_ in ireview.reviewers_rset().rows),
                          set([self.reviewer2.eid,
                               self.committer.eid]))
         req.execute('SET X use_global_groups FALSE')
         patch.cw_clear_all_caches()
         ireview = patch.cw_adapt_to('IPatchReviewControl')
-        self.assertEqual(set(x for x, in ireview.reviewers_rset().rows),
+        self.assertEqual(set(x for x,_ in ireview.reviewers_rset().rows),
                          set([self.committer.eid]))
 
 
