@@ -110,12 +110,11 @@ class RepositoryPatchesTable(EntityView):
     __regid__ = 'vcreview.repository.patches'
     __select__ = is_instance('Repository') & score_entity(lambda x: x.has_review)
 
-    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR) ' # XXX need a sub query to find patch tip
-           'GROUPBY P,PO,PB,PS '
+    rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS ' # XXX need a sub query to find patch tip
+           'GROUPBY P,PB,PS '
            'WHERE '
            '      RE branch PB, '
            '      P in_state PS, '
-           '      TR? wf_info_for P, '
            '      P patch_revision RE, '
            '      RE from_repository R, '
            '      RE author PO, '
