@@ -32,14 +32,13 @@ class AllActivePatches(view.StartupView):
     __regid__ = 'vcreview.allactivepatches'
     title = _('All active patches')
 
-    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R '
-           'GROUPBY R,P,PO,PB,PS '
-           'ORDERBY RT,PB,PO '
+    rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS,R '
+           'GROUPBY R,P,PB,PS '
+           'ORDERBY RT,PB '
            'WHERE P patch_revision RE, '
            '      RE author PO, '
            '      RE branch PB, '
            '      P in_state PS,'
-           '      TR? wf_info_for P, '
            '      RE from_repository R, '
            '      R title RT, '
            '      NOT PS name %s')
@@ -59,16 +58,15 @@ class UserWorkList(AllActivePatches):
     __regid__ = 'vcreview.patches.worklist'
     title = _('My review worklist')
 
-    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR),R '
-           'GROUPBY R,P,PO,PB,PS '
-           'ORDERBY RT,PB,PO '
+    rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS,R '
+           'GROUPBY R,P,PB,PS '
+           'ORDERBY RT,PB '
            'WHERE U eid %(u)s, '
            '      P in_state PS, '
            '      P patch_revision RE, '
            '      RE author PO, '
            '      RE branch PB, '
            '      RE from_repository R, '
-           '      TR? wf_info_for P, '
            '      R title RT, '
            # Patch is pending review  and CWUser is reviewer
            '      EXISTS(PS name "pending-review" AND P patch_reviewer U) '
@@ -96,12 +94,12 @@ class PatchesTable(tableview.TableView):
                                        **kwargs)
 
     def column_label(self, colidx, default, translate_func=None):
+        if colidx == 1:
+            return self._cw._('author')
         if colidx == 2:
             return self._cw._('patch_reviewer')
         if colidx == 3:
             return self._cw._('patch_committer')
-        if colidx == 6:
-            return self._cw.__('Transition_plural').lower()
         return super(PatchesTable, self).column_label(colidx, default, translate_func)
 
 
